set echo on
spool installDemo.log
--
def DBAUSERNAME = &1
def DBAPASSWORD = &2
def USERNAME    = &3
def PASSWORD    = &4
def TNSALIAS    = &5
def HTTPPORT    = &6
def FTPPORT     = &7
--
-- Set HTTP and FTP Ports
--
call dbms_xdb.setHTTPPort(&HTTPPORT)
/
call dbms_xdb.setFTPPort(&FTPPORT)
/
--
-- Drop and Recreate the STAT_TABLE for the demo
-- 
declare
  non_existant_table exception;
  PRAGMA EXCEPTION_INIT( non_existant_table , -20002 );
begin
--
  begin
    dbms_stats.drop_stat_table('&USERNAME','STAT_TABLE');
  exception
    when non_existant_table then
      null;
  end;
end;
/
call dbms_stats.create_stat_table('&USERNAME','STAT_TABLE')
/
--
-- Grant Required permissions for Schema Registration etc to the demo user
--
grant alter session, unlimited tablespace, create table, create view, create any directory, drop any directory to &USERNAME
/
grant all on HR.COUNTRIES to &USERNAME
/
grant all on HR.LOCATIONS to &USERNAME
/
grant all on HR.DEPARTMENTS to &USERNAME
/
grant all on HR.EMPLOYEES to &USERNAME
/
grant all on HR.JOBS to &USERNAME
/
grant all on HR.JOB_HISTORY to &USERNAME
/
grant create synonym to &USERNAME
/
grant execute on XDBPM.XDB_DEMO_HELPER_11100 to &USERNAME
/
call xdbpm.xdb_demo_helper.enableWebServicesDemo('&USERNAME')
/
--
-- Connect as the demo user
--
connect &USERNAME/&PASSWORD@&TNSALIAS
--
-- Create Home and Public Folder
--
call xdb_utilities.createHomeFolder()
/
call xdb_utilities.createPublicFolder()
/
--
-- Import the statistics
--
host imp userid=&DBAUSERNAME/&DBAPASSWORD@&TNSALIAS fromuser=XDBSTATS touser=&USERNAME file=largeDatasetStats.dmp ignore=Y
--
/*
**
** create directory dp_dir as '%DEMODIRECTORY%\LOCAL'
**
** host impdp &USERNAME/&PASSWORD@&TNSALIAS tables=stat_table remap_schema=scott:%USER% directory=dp_dir dumpfile=largeDatasetStats.dmp TABLE_EXISTS_ACTION=REPLACE
**
*/
update STAT_TABLE
set C5 = '&USERNAME'
/
quit